local mod = foundation.createMod();



-- registering map files
mod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mod:registerAssetId("maps/berry_density.png", "BERRIES_DENSITY_MAP")
mod:registerAssetId("maps/stone_density.png", "STONE_DENSITY_MAP")
mod:registerAssetId("maps/tree_density.png", "TREE_DENSITY_MAP")

-- register custom map
mod:register({
	DataType = "CUSTOM_MAP",
	Id = "MAP_EXTREMADURA",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = 10,
	MaxHeight = 90,
	VillagePathList = {
		{
			Entrance = { 100, 0, 1013 },
			Exit = { 100, 0, 202 },
		},
		{
			Entrance = { 150, 0, 1013 },
			Exit = { 150, 0, 202 },
		},
		{
			Entrance = { 200, 0, 1013 },
			Exit = { 200, 0, 13 },
		},
		{
			Entrance = { 250, 0, 1013 },
			Exit = { 250, 0, 13 },
		},
		{
			Entrance = { 300, 0, 1013 },
			Exit = { 300, 0, 13 },
		},
		{
			Entrance = { 350, 0, 1013 },
			Exit = { 350, 0, 13 },
		},
		{
			Entrance = { 400, 0, 1013 },
			Exit = { 400, 0, 13 },
		},
		{
			Entrance = { 450, 0, 1013 },
			Exit = { 450, 0, 13 },
		},
		{
			Entrance = { 500, 0, 1013 },
			Exit = { 500, 0, 13 },
		},
	},
	SpawnList = {
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 238, 37, 897 },
            Orientation = { 0 , 10, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 327, 43, 890 },
            Orientation = { 0 , -37, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 394, 48, 893 },
            Orientation = { 0 , 27, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 822, 27, 701 },
            Orientation = { 0 , 59, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 931, 36, 653 },
            Orientation = { 0 , 26, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 757, 51, 155 },
            Orientation = { 0 , -123, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 415, 42, 97 },
            Orientation = { 0 , 73, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 338, 46, 153 },
            Orientation = { 0 , 28, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 305, 43, 360 },
            Orientation = { 0 , -131, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 133, 49, 847 },
            Orientation = { 0 , -45, 0 },
        },
	},
	DensitySpawnList = {
        {
			-- creating Tree Density Map
			DensityMap = "TREE_DENSITY_MAP",
			Density = 0.20,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_TREE_OAK" },
						RandomWeight = 2.0,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.8,
							Max = 1.2
					},
						ColorRange = {
							Min = { 0.8,0.8,0.8,1 },
							Max = { 1,1,1,1 }
					}
				},
				{
						PrefabList = { "PREFAB_TREE_SYCAMORE" },
						RandomWeight = 1.0,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.8,
							Max = 1.2
					},
						ColorRange = {
							Min = { 0.8,0.8,0.8,1 },
							Max = { 1,1,1,1 }
					}
				},
				{
						PrefabList = { "PREFAB_TREE_POPLAR" },
						RandomWeight = 0.5,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.8,
							Max = 1.2
					},
						ColorRange = {
							Min = { 0.8,0.8,0.8,1 },
							Max = { 1,1,1,1 }
					}
				}
			}
		},
        {
			-- Create forest of berry bushes
			DensityMap = "BERRIES_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_BERRIES" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
			-- Create stone
			DensityMap = "STONE_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_ROCK" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
	}
})
